Read chromosomes included in .(m)cool files
readCoolChroms(file, resolution = NULL)
Arguments
- file
A character value specifying the path to the .(m)cool file
- resolution
optional, specify which resolution(s) to read
chromosomes from. Default is all resolutions in `file`.
Value
Data frame or list of data frames of chromosome names and lengths
Author
Sarah Parker, Nicole Kramer